package com.backstopsolutions.activemqtest;

import javax.annotation.Resource;
import javax.ejb.ActivationConfigProperty;
import javax.ejb.EJBException;
import javax.ejb.MessageDriven;
import javax.ejb.MessageDrivenBean;
import javax.ejb.MessageDrivenContext;
import javax.ejb.TransactionAttribute;
import javax.ejb.TransactionAttributeType;
import javax.ejb.TransactionManagement;
import javax.ejb.TransactionManagementType;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageListener;
import javax.jms.TextMessage;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.jboss.ejb3.annotation.ResourceAdapter;

@MessageDriven(name = "LogBean",
        activationConfig =
              {
                 @ActivationConfigProperty(propertyName = "destinationType", propertyValue = "javax.jms.Queue"),
                 @ActivationConfigProperty(propertyName = "destination", propertyValue = "queue/logqueue"),
                 @ActivationConfigProperty(propertyName = "acknowledgeMode", propertyValue = "Auto-acknowledge"),
                 @ActivationConfigProperty(propertyName = "maxSession", propertyValue = "2"),
              })
@TransactionManagement(value= TransactionManagementType.CONTAINER)
@TransactionAttribute(value= TransactionAttributeType.REQUIRED)
@ResourceAdapter("hornetq-ra.rar")
public class LogBean implements MessageDrivenBean, MessageListener {
    @Resource
    protected MessageDrivenContext ctx;

    Log logger = LogFactory.getLog(LogBean.class);

    public void setMessageDrivenContext(MessageDrivenContext messageDrivenContext) {
        this.ctx = messageDrivenContext;
    }

    public void ejbRemove() throws EJBException {}
    
    public void onMessage(Message msg) {
        TextMessage textMsg = (TextMessage) msg;
        try {
            logger.info("Received message: " + textMsg.getText().trim() + " from host: " + msg.getStringProperty("sourceServer"));
            int id = msg.getIntProperty("id");
            if(id % 2 == 0) {
                try {
                    Thread.sleep(1000);
                } catch (InterruptedException ie) {
                    logger.warn("You interrupted me, stop doing that!  I need my beauty sleep!");
                }
            }
        } catch (JMSException jmse) {
            logger.error("Failed to get the text of the message!", jmse);
            throw new RuntimeException("Make sure the message is redelivered", jmse);
        }
    }
}
